@@ -477,10 +477,10 @@ void dw_sbvar_estimate_command_line(int nargs, char **args)
 	    info->cmd->out_header=dw_DuplicateString(info->cmd->MLE ? "MLE: " : "Posterior mode: ");
 
 	  /* Open temporary final output file */
-	  if (f_intermediate=dw_CreateTextFile(info->intermediate_output_filename))
+	  if ((f_intermediate=dw_CreateTextFile(info->intermediate_output_filename)))
 	    {
 	      sprintf(filename=(char*)dw_malloc(5+strlen(info->final_output_filename)),"%s.tmp",info->final_output_filename);
-	      if (f_final=dw_CreateTextFile(filename))
+	      if ((f_final=dw_CreateTextFile(filename)))
 		{
 		  Write_VAR_Specification(f_final,(char*)NULL,model);
 		  fprintf(f_final,"Specification file: %s\n",info->cmd->specification_filename_actual);
@@ -626,7 +626,7 @@ void dw_sbvar_estimate_command_line(int nargs, char **args)
 		  
 		  /* Write Free Parameter File */
 		  filename=CreateFilenameFromTag("%sest_free_%s.out",info->cmd->out_tag,info->cmd->out_directory);
-		  if (f_free = fopen(filename, "wt"))
+		  if ((f_free = fopen(filename, "wt")))
 		    {
 		      max_parameters=CreateVector(nparms);
 		      fprintf(f_free,"%le %le ",LogPosterior_StatesIntegratedOut(model),LogLikelihood_StatesIntegratedOut(model));
@@ -640,7 +640,7 @@ void dw_sbvar_estimate_command_line(int nargs, char **args)
 
 		  /* Write flat file */
 		  filename=CreateFilenameFromTag("%sest_flat_header_%s.out",info->cmd->out_tag,info->cmd->out_directory);
-		  if (f_out=fopen(filename,"wt"))
+		  if ((f_out=fopen(filename,"wt")))
 		    {     
 		      WriteBaseTransitionMatricesFlat_Headers(f_out,model);
 		      Write_VAR_ParametersFlat_Headers(f_out,model);
@@ -649,7 +649,7 @@ void dw_sbvar_estimate_command_line(int nargs, char **args)
 		    }
 		  dw_free(filename);
 		  filename=CreateFilenameFromTag("%sest_flat_%s.out",info->cmd->out_tag,info->cmd->out_directory);
-		  if (f_out=fopen(filename,"wt"))
+		  if ((f_out=fopen(filename,"wt")))
 		    {     
 		      WriteBaseTransitionMatricesFlat(f_out,(char*)NULL,model,"%lf ");
 		      if (dw_FindArgument_String(nargs,args,"nd1") >= 0)
@@ -669,7 +669,7 @@ void dw_sbvar_estimate_command_line(int nargs, char **args)
 
 		  /* Write aux output */
 		  filename=CreateFilenameFromTag("%sest_aux_%s.out",info->cmd->out_tag,info->cmd->out_directory);
-		  if (f_out=fopen(filename,"wt"))
+		  if ((f_out=fopen(filename,"wt")))
 		    {
 		      fprintf(f_out,"""ln(P(y[t]|Y[t-1],Z[t],theta,Q))"",""E[y[t]|Y[t-1],Z[t],theta,Q]""\n");
 
