@@ -284,7 +284,7 @@ static void print_info_gaussian(FILE *f_out, TElliptical *elliptical)
 TElliptical* CreateElliptical_Gaussian(int dim, TVector mean, TMatrix variance)
 {
   TElliptical* elliptical;
-  if (elliptical=CreateElliptical_TruncatedGaussian(dim,mean,variance,0.0,PLUS_INFINITY))
+  if ((elliptical=CreateElliptical_TruncatedGaussian(dim,mean,variance,0.0,PLUS_INFINITY)))
     {
       elliptical->type="gaussian";
       elliptical->draw_vector=draw_gaussian;
@@ -390,7 +390,7 @@ TElliptical* CreateElliptical_TruncatedPower(int dim, TVector center, TMatrix sc
       return (TElliptical*)NULL;
     }
 
-  if (elliptical=CreateElliptical(dim,center,scale))
+  if ((elliptical=CreateElliptical(dim,center,scale)))
     {
       elliptical->variance_scale=VarianceScale_TruncatedPower(dim,lower_bound,upper_bound,power);
       elliptical->type="truncated power";
@@ -433,7 +433,7 @@ static void print_info_power(FILE *f_out, TElliptical *elliptical)
 TElliptical* CreateElliptical_Power(int dim, TVector center, TMatrix scale, PRECISION bound, PRECISION power)
 {
   TElliptical *elliptical;
-  if (elliptical=CreateElliptical_TruncatedPower(dim,center,scale,0.0,bound,power))
+  if ((elliptical=CreateElliptical_TruncatedPower(dim,center,scale,0.0,bound,power)))
     {
       elliptical->print_info=print_info_power;
       elliptical->type="power";
@@ -469,7 +469,7 @@ static PRECISION logdensity_radius_uniform(PRECISION radius, TElliptical *ellipt
 TElliptical* CreateElliptical_Uniform(int dim, TVector center, TMatrix scale, PRECISION lower_bound, PRECISION upper_bound)
 {
   TElliptical* elliptical;
-  if (elliptical=CreateElliptical_TruncatedPower(dim,center,scale,lower_bound,upper_bound,dim))
+  if ((elliptical=CreateElliptical_TruncatedPower(dim,center,scale,lower_bound,upper_bound,dim)))
     {
       elliptical->type="uniform";
       elliptical->logdensity_radius=logdensity_radius_uniform;
@@ -597,7 +597,7 @@ TElliptical* CreateElliptical_Step(int dim, TVector center, TMatrix scale, PRECI
   TElliptical* elliptical;
   TElliptical_step *data;
 
-  if (elliptical=CreateElliptical(dim,center,scale))
+  if ((elliptical=CreateElliptical(dim,center,scale)))
     {
       elliptical->variance_scale=VarianceScale_Step(dim,table,m);
       elliptical->type="step";
