@@ -152,10 +152,12 @@ int dw_SetError(int err, char *msg)
 	break;
       }
   if (VerboseErrors & ERROR_FLAG)
-    if (f_err)
-      fprintf(f_err,"%s\n",ERROR_MESSAGE);
-    else
-      printf("%s\n",ERROR_MESSAGE);
+    {
+      if (f_err)
+        fprintf(f_err,"%s\n",ERROR_MESSAGE);
+      else
+        printf("%s\n",ERROR_MESSAGE);
+    }
   if (TerminalErrors & ERROR_FLAG) dw_exit(ERROR_FLAG);
   return rtrn;
 }
@@ -265,8 +267,8 @@ int dw_CreateErrorMessageFile(char *filename)
     {
       if (f_err) fclose(f_err);
       if (filename_err) dw_free(filename_err);
-      if (f_err=fopen(filename,"wt"))
-	if (filename_err=(char*)malloc(strlen(filename)+1))
+      if ((f_err=fopen(filename,"wt")))
+	if ((filename_err=(char*)malloc(strlen(filename)+1)))
 	  {
 	    strcpy(filename_err,filename);
 	    return 1;
@@ -297,8 +299,8 @@ int dw_AppendErrorMessageFile(char *filename)
     {
       if (f_err) fclose(f_err);
       if (filename_err) dw_free(filename_err);
-      if (f_err=fopen(filename,"at"))
-	if (filename_err=(char*)malloc(strlen(filename)+1))
+      if ((f_err=fopen(filename,"at")))
+	if ((filename_err=(char*)malloc(strlen(filename)+1)))
 	  {
 	    strcpy(filename_err,filename);
 	    return 1;
