@@ -2,7 +2,7 @@ function aggregate(ofile, dynopt, rootfolder, varargin)
 
 % Agregates cherry-picked models.
 
-% Copyright (C) 2019-2021 Dynare Team
+% Copyright © 2019-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -84,7 +84,7 @@ for i=1:length(varargin)
             end
             % Ensure that the equation tag name matches the LHS variable.
             eqtagname = regexp(model{j}, 'name=''(\w*)''', 'match');
-            [lhs, ~] = getequation(model{j+1});
+            lhs = getequation(model{j+1});
             endovar = getendovar(lhs);
             eqtagname_ = strcat('name=''', endovar{1}, '''');
             if ~isempty(eqtagname)
@@ -92,7 +92,7 @@ for i=1:length(varargin)
                     model{j} = strrep(model{j}, eqtagname{1}, eqtagname_);
                 end
             else
-                model{j} = eqtagname_;
+                model{j} = strcat('[', eqtagname_, ']');
             end
             % Add equation tag with block name.
             if ~isempty(rootfolder)
@@ -113,11 +113,7 @@ for i=1:length(varargin)
     end
 end
 eqlist = eqlist(1:eqnum,:);
-if isoctave && octave_ver_less_than('6')
-    [~, idx] = unique_stable(eqlist(:,1));
-else
-    [~, idx] = unique(eqlist(:,1), 'stable');
-end
+[~, idx] = unique(eqlist(:,1), 'stable');
 eqlist = eqlist(idx, :);
 
 % Get endogenous variables.
@@ -140,11 +136,7 @@ for i=1:length(varargin)
     fclose(fid);
 end
 elist = elist(1:enum,:);
-if isoctave && octave_ver_less_than('6')
-    [~, idx] = unique_stable(elist(:,1));
-else
-    [~, idx] = unique(elist(:,1), 'stable');
-end
+[~, idx] = unique(elist(:,1), 'stable');
 elist = elist(idx,:);
 
 % Get exogenous variables.
@@ -172,15 +164,11 @@ for i=1:length(varargin)
     fclose(fid);
 end
 xlist = xlist(1:xnum,:);
-if isoctave && octave_ver_less_than('6')
-    [~, idx] = unique_stable(xlist(:,1));
-else
-    [~, idx] = unique(xlist(:,1), 'stable');
-end
+[~, idx] = unique(xlist(:,1), 'stable');
 xlist = xlist(idx,:);
 
 % Get parameter values.
-calibration = '';
+pArray = cell(0, 3);
 for i=1:length(varargin)
     fid = fopen(sprintf('%s/parameter-values.inc', varargin{i}));
     if fid<0
@@ -190,12 +178,61 @@ for i=1:length(varargin)
     end
     cline = fgetl(fid);
     while ischar(cline)
-        calibration = sprintf('%s\n%s', calibration, cline);
+        tmp = textscan(cline, '%s = %f', 'Delimiter', ';= ');
+        pArray(end+1,1) = tmp{1};
+        pArray{end,2} = tmp{2};
+        pArray{end,3} = varargin{i};
         cline = fgetl(fid);
     end
     fclose(fid);
 end
 
+if rows(pArray)>1
+    irow = 2;
+    while irow<=rows(pArray)
+        ispreviouslydefined = strcmpi(pArray{irow,1}, pArray(1:irow-1,1));
+        if any(ispreviouslydefined)
+            if isnan(pArray{ispreviouslydefined,2})
+                if ~isnan(pArray{irow,2})
+                    % Remove first assignment (with NaN)
+                    pArray(ispreviouslydefined,:) = [];
+                else
+                    % Remove second assignment (both assigments are NaNs)
+                    pArray(irow,:) = [];
+                end
+            elseif isnan(pArray{irow,2})
+                % New assigment is NaN but not the previous one.
+                pArray(irow,:) = [];
+            else
+                % Check that the values are identical in both assignments.
+                if abs(pArray{ispreviouslydefined,2}-pArray{irow,2})>1e-10
+                    error('More than one assigment for parameter %s with different values (see cherrypicked files in %s and %s).', pArray{irow,1}, pArray{irow,3}, pArray{ispreviouslydefined,3});
+                else
+                    % Remove last assignement (duplicate).
+                    pArray(irow,:) = [];
+                end
+            end
+        else
+            irow = irow+1;
+        end
+    end
+end
+
+if any(isnan([pArray{:,2}]))
+    msg  ='';
+    for i=1:rows(pArray)
+        if isnan(pArray{i,2})
+            msg = sprintf('%sParameter %s has no value.\n', msg, pArray{i,1});
+        end
+    end
+    error(msg)
+end
+
+calibration = '';
+for i=1:rows(pArray)
+    calibration = sprintf('%s%s = %s;\n', calibration, pArray{i,1}, num2str(pArray{i,2}, 16));
+end
+
 % Move the endogenous variables which are not LHS of an equation
 % into the set of exogenous variables.
 [~, i1] = intersect(elist(:,1), eqlist(:,1));
@@ -228,6 +265,7 @@ end
 if ~isempty(firstline)
     fprintf(fid, '%s\n\n', firstline);
 end
+% Print list of endogenous variables.
 fprintf(fid, 'var\n');
 for i=1:rows(elist)
     if size(elist,2)==1 || isempty(elist{i,2})
@@ -236,16 +274,19 @@ for i=1:rows(elist)
         fprintf(fid, '\t%s %s\n', elist{i,1}, elist{i,2});
     end
 end
-if ~isempty(plist)
-    fprintf(fid, ';\n\n');
+fprintf(fid, ';\n\n');
+if exist('plist', 'var') && ~isempty(plist)
+    % Print list of parameters.
     fprintf(fid, 'parameters\n');
     for i=1:length(plist)
         fprintf(fid, '\t%s\n', plist{i});
     end
     fprintf(fid, ';\n\n');
+    % Print calibration.
     fprintf(fid, calibration);
 end
-if ~isempty(xlist)
+if exist('xlist', 'var') && ~isempty(xlist)
+    % Print list of exogenous variables.
     fprintf(fid, '\n\n');
     fprintf(fid, 'varexo\n');
     for i=1:rows(xlist)
@@ -255,8 +296,18 @@ if ~isempty(xlist)
             fprintf(fid, '\t%s %s\n', xlist{i,1}, xlist{i,2});
         end
     end
+    fprintf(fid, ';\n');
 end
-fprintf(fid, ';\n\n');
+skipline(1, fid)
+% Provide an interface to flip endogenous and exogenous variables. Active if only macrovariable
+% InvertModel is set to True. The calls to the change_type command must be provided in the file
+% model-inversion-setup.inc (in the current folder).
+fprintf(fid, '@#ifdef InvertModel\n');
+fprintf(fid, '    @#if InvertModel\n');
+fprintf(fid, '        @#include "model-inversion-setup.inc"\n');
+fprintf(fid, '    @#endif\n');
+fprintf(fid, '@#endif\n');
+skipline(1, fid)
 fprintf(fid, 'model;\n\n');
 for i=1:rows(eqlist)
     if isempty(eqlist{i,4})
