@@ -1,5 +1,5 @@
 function forecasts = backward_model_forecast(initialcondition, listofvariables, periods, withuncertainty)
-
+%function forecasts = backward_model_forecast(initialcondition, listofvariables, periods, withuncertainty)
 % Returns unconditional forecasts.
 %
 % INPUTS
@@ -10,7 +10,7 @@ function forecasts = backward_model_forecast(initialcondition, listofvariables,
 % OUTPUTS
 % - forecast            [dseries]
 
-% Copyright (C) 2017-2018 Dynare Team
+% Copyright © 2017-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -31,7 +31,7 @@ global M_ options_ oo_
 
 % Check that the model is actually backward
 if M_.maximum_lead
-    error(['backward_model_forecast:: The specified model is not backward looking!'])
+    error('backward_model_forecast:: The specified model is not backward looking!')
 end
 
 % Initialize returned argument.
@@ -63,7 +63,7 @@ for i=1:M_.exo_nbr
 end
 
 % Set up initial conditions
-[initialcondition, periods, innovations, DynareOptions, DynareModel, DynareOutput, endonames, exonames, nx, ny1, iy1, jdx, model_dynamic, y] = ...
+[initialcondition, periods, innovations, options_local, M_local, oo_local, endonames, ~, dynamic_resid, dynamic_g1] = ...
     simul_backward_model_init(initialcondition, periods, options_, M_, oo_, zeros(periods, M_.exo_nbr));
 
 % Get vector of indices for the selected endogenous variables.
@@ -85,16 +85,20 @@ end
 
 % Get the covariance matrix of the shocks.
 if withuncertainty
-    Sigma = M_.Sigma_e + 1e-14*eye(M_.exo_nbr);
-    sigma = transpose(chol(Sigma));
+    sigma = get_lower_cholesky_covariance(M_.Sigma_e,options_.add_tiny_number_to_cholesky);
 end
 
 % Compute forecast without shock
 if options_.linear
-    ysim__0 = simul_backward_linear_model_(initialcondition, periods, DynareOptions, DynareModel, DynareOutput, innovations, nx, ny1, iy1, jdx, model_dynamic);
+    [ysim__0, errorflag] = simul_backward_linear_model_(initialcondition, periods, options_local, M_local, oo_local, innovations, dynamic_resid, dynamic_g1);
 else
-    ysim__0 = simul_backward_nonlinear_model_(initialcondition, periods, DynareOptions, DynareModel, DynareOutput, innovations, iy1, model_dynamic);
+    [ysim__0, errorflag] = simul_backward_nonlinear_model_(initialcondition, periods, options_local, M_local, oo_local, innovations, dynamic_resid, dynamic_g1);
 end
+
+if errorflag
+    error('Simulation failed.')
+end
+
 forecasts.pointforecast = dseries(transpose(ysim__0(idy,:)), initialcondition.init, listofvariables);
 
 % Set first period of forecast
@@ -106,9 +110,12 @@ if withuncertainty
     for i=1:B
         innovations = transpose(sigma*randn(M_.exo_nbr, periods));
         if options_.linear
-            [ysim__, xsim__] = simul_backward_linear_model_(initialcondition, periods, DynareOptions, DynareModel, DynareOutput, innovations, nx, ny1, iy1, jdx, model_dynamic);
+            [ysim__, ~, errorflag] = simul_backward_linear_model_(initialcondition, periods, options_local, M_local, oo_local, innovations, dynamic_resid, dynamic_g1);
         else
-            [ysim__, xsim__] = simul_backward_nonlinear_model_(initialcondition, periods, DynareOptions, DynareModel, DynareOutput, innovations, iy1, model_dynamic);
+            [ysim__, ~, errorflag] = simul_backward_nonlinear_model_(initialcondition, periods, options_local, M_local, oo_local, innovations, dynamic_resid, dynamic_g1);
+        end
+        if errorflag
+            error('Simulation failed.')
         end
         ArrayOfForecasts(:,:,i) = ysim__(idy,:);
     end
@@ -120,4 +127,4 @@ if withuncertainty
     ArrayOfForecasts = sort(ArrayOfForecasts, 3);
     forecasts.lb = dseries(transpose(ArrayOfForecasts(:,:,round(0.025*B))), initialcondition.init, listofvariables);
     forecasts.ub = dseries(transpose(ArrayOfForecasts(:,:,round(0.975*B))), initialcondition.init, listofvariables);
-end
\ No newline at end of file
+end
