@@ -1,5 +1,5 @@
-function [endogenousvariables, exogenousvariables] = backward_model_inversion(constraints, exogenousvariables, initialconditions, endo_names, exo_names, freeinnovations, DynareModel, DynareOptions, DynareOutput)
-
+function [endogenousvariables, exogenousvariables] = backward_model_inversion(constraints, exogenousvariables, initialconditions, endo_names, exo_names, freeinnovations, M_, options_, oo_)
+% [endogenousvariables, exogenousvariables] = backward_model_inversion(constraints, exogenousvariables, initialconditions, endo_names, exo_names, freeinnovations, M_, options_, oo_)
 % INPUTS
 % - constraints         [dseries]        with N constrained endogenous variables from t1 to t2.
 % - exogenousvariables  [dseries]        with Q exogenous variables.
@@ -7,6 +7,9 @@ function [endogenousvariables, exogenousvariables] = backward_model_inversion(co
 % - endo_names          [cell]           list of endogenous variable names.
 % - exo_names           [cell]           list of exogenous variable names.
 % - freeinstruments     [cell]           list of exogenous variable names used to control the constrained endogenous variables.
+% - M_                  [structure]      describing the model
+% - options_            [structure]      describing the options
+% - oo_                 [structure]      storing the results
 %
 % OUTPUTS
 % - endogenous          [dseries]
@@ -14,7 +17,7 @@ function [endogenousvariables, exogenousvariables] = backward_model_inversion(co
 %
 % REMARKS
 
-% Copyright (C) 2017 Dynare Team
+% Copyright © 2017-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -31,24 +34,21 @@ function [endogenousvariables, exogenousvariables] = backward_model_inversion(co
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
-% Get indices for the calibrated and free innovations.
+% Get indices for the free innovations.
 freeinnovations_id = zeros(length(freeinnovations), 1);
-if length(freeinnovations)<DynareModel.exo_nbr
+if length(freeinnovations)<M_.exo_nbr
     for i=1:length(freeinnovations)
         freeinnovations_id(i) = find(strcmp(freeinnovations{i}, exo_names));
     end
-    calibratedinnovations_id = setdiff(transpose(1:length(exo_names)), freeinnovations_id);
 else
     freeinnovations_id = transpose(1:length(exo_names));
-    calibratedinnovations_id = [];
 end
 
 nxfree = length(freeinnovations_id);
-nxcalb = length(calibratedinnovations_id);
 
 % Get indices for the the controlled and free endogenous variables.
 controlledendogenousvariables_id = zeros(length(freeinnovations), 1);
-if length(freeinnovations)<DynareModel.endo_nbr
+if length(freeinnovations)<M_.endo_nbr
     for i=1:length(freeinnovations)
         controlledendogenousvariables_id(i) = find(strcmp(constraints.name{i}, endo_names));
     end
@@ -61,56 +61,46 @@ end
 nyfree = length(freeendogenousvariables_id);
 nyctrl = length(controlledendogenousvariables_id);
 
-% Get indices of variables appearing at time t-1.
-iy1 = find(DynareModel.lead_lag_incidence(1,:)>0);
-
-% Get indices of variables appearing at time t.
-iy0 = find(DynareModel.lead_lag_incidence(2,:)>0);
-
-% Set indices for trust_region algorithm.
-idx = 1:DynareModel.endo_nbr;
-jdx = 1:(nyfree+nxfree);
-
 % Build structure to be passed to the objective function.
 ModelInversion.nyfree = nyfree;
 ModelInversion.nyctrl = nyctrl;
 ModelInversion.nxfree = nxfree;
-ModelInversion.nxcalb = nxcalb;
-ModelInversion.y_constrained_id = vec(DynareModel.lead_lag_incidence(2,controlledendogenousvariables_id));
-ModelInversion.y_free_id = vec(DynareModel.lead_lag_incidence(2,freeendogenousvariables_id));
+ModelInversion.y_constrained_id = controlledendogenousvariables_id;
+ModelInversion.y_free_id = freeendogenousvariables_id;
 ModelInversion.x_free_id = freeinnovations_id;
-ModelInversion.J_id = [ModelInversion.y_free_id ; sum(DynareModel.lead_lag_incidence(:)>0)+ModelInversion.x_free_id];
+ModelInversion.J_id = [M_.endo_nbr+ModelInversion.y_free_id ; 3*M_.endo_nbr+ModelInversion.x_free_id];
 
-% Get the name of the dynamic model routines.
-model_dynamic = str2func([DynareModel.fname,'.dynamic']);
-model_dtransf = str2func('dynamic_backward_model_for_inversion');
+% Get function handles to the dynamic model routines.
+dynamic_resid = str2func([M_.fname '.sparse.dynamic_resid']);
+dynamic_g1 = str2func([M_.fname '.sparse.dynamic_g1']);
 
 % Initialization of the returned simulations (endogenous variables).
-Y = NaN(DynareModel.endo_nbr, nobs(constraints));
-Y = [transpose(initialconditions{DynareModel.endo_names{:}}(constraints.dates(1)-1).data), Y];
+Y = NaN(M_.endo_nbr, nobs(constraints));
+Y = [transpose(initialconditions{M_.endo_names{:}}(constraints.dates(1)-1).data), Y];
 for i=1:nyctrl
     Y(controlledendogenousvariables_id(i),2:end) = transpose(constraints.data(:,i));
 end
 
 % Exogenous variables.
-X = exogenousvariables.data;
+X = exogenousvariables{exo_names{:}}.data;
 
 % Inversion of the model, solvers for the free endogenous and exogenous variables (call a Newton-like algorithm in each period).
 ity = 2;
 itx = find(exogenousvariables.dates==constraints.dates(1));
-DynareOptions.solve_algo=4;
 for t = 1:nobs(constraints)
     % Set the lagged values of the endogenous variables.
-    ylag = Y(iy1,ity-1);
+    ylag = Y(:,ity-1);
     % Set the current values of the constrained endogenous variables.
     ycur = Y(controlledendogenousvariables_id,ity);
     % Vector z gather the free endogenous variables (initialized with lagged
     % values) and the free exogenous variables (initialized with 0).
     z = [Y(freeendogenousvariables_id,ity-1); zeros(nxfree, 1)];
     % Solves for z.
-    [z, failed] = dynare_solve(model_dtransf, z, DynareOptions, model_dynamic, ylag, ycur, X, DynareModel.params, DynareOutput.steady_state, itx, ModelInversion);
+    [z, failed, ~, ~, errorcode] = dynare_solve(@dynamic_backward_model_for_inversion, z, ...
+                                                options_.simul.maxit, options_.dynatol.f, options_.dynatol.x, ...
+                                                options_, dynamic_resid, dynamic_g1, ylag, ycur, X(itx,:), M_.params, oo_.steady_state, M_.dynamic_g1_sparse_rowval, M_.dynamic_g1_sparse_colval, M_.dynamic_g1_sparse_colptr, ModelInversion);
     if failed
-        error('Enable to solve the system of equations!')
+        error('Nonlinear solver failed with errorcode=%i', errorcode)
     end
     % Update the matrix of exogenous variables.
     X(itx,freeinnovations_id) = z(nyfree+(1:nxfree));
@@ -124,4 +114,28 @@ for t = 1:nobs(constraints)
 end
 
 endogenousvariables = dseries(Y(:,2:end)', constraints.dates(1), endo_names);
-exogenousvariables = dseries(X(find(exogenousvariables.dates==constraints.dates(1))+(0:(nobs(constraints)-1)),:), constraints.dates(1), exo_names);
\ No newline at end of file
+exogenousvariables = dseries(X(find(exogenousvariables.dates==constraints.dates(1))+(0:(nobs(constraints)-1)),:), constraints.dates(1), exo_names);
+
+
+function [r, J] = dynamic_backward_model_for_inversion(z, dynamic_resid, dynamic_g1, ylag, ycur, x, params, steady_state, sparse_rowval, sparse_colval, sparse_colptr, ModelInversion)
+
+endo_nbr = ModelInversion.nyfree+ModelInversion.nyctrl;
+
+% Set up y
+y = [ylag; zeros(2*endo_nbr, 1)];
+
+y(endo_nbr+ModelInversion.y_constrained_id) = ycur;
+if ModelInversion.nyfree
+    y(endo_nbr+ModelInversion.y_free_id) = z(1:ModelInversion.nyfree);
+end
+
+% Update x
+x(ModelInversion.x_free_id) = z(ModelInversion.nyfree+(1:ModelInversion.nxfree));
+
+[r, T_order, T] = dynamic_resid(y, x, params, steady_state);
+
+if nargout>1
+    Jacobian = dynamic_g1(y, x, params, steady_state, sparse_rowval, ...
+                          sparse_colval, sparse_colptr, T_order, T);
+    J = Jacobian(:, ModelInversion.J_id);
+end
