@@ -1,9 +1,9 @@
-function [initialconditions, samplesize, innovations, DynareOptions, DynareModel, DynareOutput, endonames, exonames, nx, ny1, iy1, jdx, model_dynamic, y] = ...
-    simul_backward_model_init(initialconditions, samplesize, DynareOptions, DynareModel, DynareOutput, innovations)
+function [initialconditions, samplesize, innovations, options_, M_, oo_, endonames, exonames, dynamic_resid, dynamic_g1, y] = ...
+    simul_backward_model_init(initialconditions, samplesize, options_, M_, oo_, innovations)
 
 % Initialization of the routines simulating backward models.
 
-% Copyright (C) 2017-2019 Dynare Team
+% Copyright © 2017-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -21,7 +21,7 @@ function [initialconditions, samplesize, innovations, DynareOptions, DynareModel
 % along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
 % Test if the model is backward.
-if DynareModel.maximum_lead
+if M_.maximum_lead
     error('simul_backward_nonlinear_model:: The specified model is not backward looking!')
 end
 
@@ -30,39 +30,39 @@ if ~(isdseries(initialconditions) || isempty(initialconditions))
     error('First input argument must be a dseries object or an empty array!')
 end
 
-% If initialconditions is empty instantiates a dseries object with the informations available in DynareModel.endo_histval.
+% If initialconditions is empty instantiates a dseries object with the informations available in M_.endo_histval.
 if isempty(initialconditions)
-    yinitdata = zeros(DynareModel.orig_endo_nbr, DynareModel.orig_maximum_lag);
-    yinitdata(:,1) = DynareModel.endo_histval(1:DynareModel.orig_endo_nbr);
-    xinitdata = zeros(DynareModel.exo_nbr, DynareModel.orig_maximum_lag);
-    if DynareModel.orig_maximum_endo_lag>1
-        for i = 1:length(DynareModel.aux_vars)
-            if DynareModel.aux_vars(i).type==1
-                yinitdata(DynareModel.aux_vars(i).orig_index, abs(DynareModel.aux_vars(i).orig_lead_lag)+1) = ...
-                    DynareModel.endo_histval(DynareModel.orig_endo_nbr+i);
+    yinitdata = zeros(M_.orig_endo_nbr, M_.orig_maximum_lag);
+    yinitdata(:,1) = M_.endo_histval(1:M_.orig_endo_nbr);
+    xinitdata = zeros(M_.exo_nbr, M_.orig_maximum_lag);
+    if M_.orig_maximum_endo_lag>1
+        for i = 1:length(M_.aux_vars)
+            if M_.aux_vars(i).type==1
+                yinitdata(M_.aux_vars(i).orig_index, abs(M_.aux_vars(i).orig_lead_lag)+1) = ...
+                    M_.endo_histval(M_.orig_endo_nbr+i);
             end
         end
         yinitdata = flip(yinitdata, 2);
     end
-    if DynareModel.orig_maximum_exo_lag>0
-        for i = 1:length(DynareModel.aux_vars)
-            if DynareModel.aux_vars(i).type==3
-                xinitdata(DynareModel.aux_vars(i).orig_index, abs(DynareModel.aux_vars(i).orig_lead_lag)+1) = ...
-                    DynareModel.endo_histval(DynareModel.orig_endo_nbr+i);
+    if M_.orig_maximum_exo_lag>0
+        for i = 1:length(M_.aux_vars)
+            if M_.aux_vars(i).type==3
+                xinitdata(M_.aux_vars(i).orig_index, abs(M_.aux_vars(i).orig_lead_lag)+1) = ...
+                    M_.endo_histval(M_.orig_endo_nbr+i);
             end
         end
         xinitdata = flip(xinitdata, 2);
     end
     initialconditions = dseries([transpose(yinitdata) transpose(xinitdata)], '1Y', ...
-                                vertcat(DynareModel.endo_names(1:DynareModel.orig_endo_nbr), DynareModel.exo_names));
+                                vertcat(M_.endo_names(1:M_.orig_endo_nbr), M_.exo_names));
 end
 
-[initialconditions, info] = checkdatabase(initialconditions, DynareModel, false, true);
+initialconditions = checkdatabase(initialconditions, M_, false, true);
 
 % Test if the first argument contains all the lagged endogenous variables
-endonames = DynareModel.endo_names;
+endonames = M_.endo_names;
 missingendogenousvariables = setdiff(endonames, initialconditions.name);
-endolags = get_lags_on_endogenous_variables(DynareModel);
+endolags = get_lags_on_endogenous_variables(M_);
 endolags_ = endolags(find(endolags));
 endowithlagnames = endonames(find(endolags));
 if ~isempty(missingendogenousvariables)
@@ -103,9 +103,9 @@ if missinginitialcondition
 end
 
 % If the model has lags on the exogenous variables, test if we have corresponding initial conditions.
-exonames = DynareModel.exo_names;
+exonames = M_.exo_names;
 missingexogenousvariables = setdiff(exonames, initialconditions.name);
-exolags = get_lags_on_exogenous_variables(DynareModel);
+exolags = get_lags_on_exogenous_variables(M_);
 exolags_ = exolags(find(exolags));
 exowithlagnames = exonames(find(exolags));
 if ~isempty(missingexogenousvariables)
@@ -147,57 +147,52 @@ end
 
 if nargin<6 || isempty(innovations)
     % Set the covariance matrix of the structural innovations.
-    variances = diag(DynareModel.Sigma_e);
-    number_of_shocks = length(DynareModel.Sigma_e);
+    variances = diag(M_.Sigma_e);
+    number_of_shocks = length(M_.Sigma_e);
     positive_var_indx = find(variances>0);
     effective_number_of_shocks = length(positive_var_indx);
-    covariance_matrix = DynareModel.Sigma_e(positive_var_indx,positive_var_indx);
+    covariance_matrix = M_.Sigma_e(positive_var_indx,positive_var_indx);
     covariance_matrix_upper_cholesky = chol(covariance_matrix);
     % Set seed to its default state.
-    if DynareOptions.bnlms.set_dynare_seed_to_default
-        set_dynare_seed('default');
+    if options_.bnlms.set_dynare_seed_to_default
+        options_=set_dynare_seed_local_options(options_,'default');
     end
     % Simulate structural innovations.
-    switch DynareOptions.bnlms.innovation_distribution
+    switch options_.bnlms.innovation_distribution
       case 'gaussian'
-        DynareOutput.bnlms.shocks = randn(samplesize,effective_number_of_shocks)*covariance_matrix_upper_cholesky;
+        oo_.bnlms.shocks = randn(samplesize,effective_number_of_shocks)*covariance_matrix_upper_cholesky;
       otherwise
-        error(['simul_backward_nonlinear_model:: ' DynareOption.bnlms.innovation_distribution ' distribution for the structural innovations is not (yet) implemented!'])
+        error(['simul_backward_nonlinear_model:: ' options_.bnlms.innovation_distribution ' distribution for the structural innovations is not (yet) implemented!'])
     end
-    % Put the simulated innovations in DynareOutput.exo_simul.
-    DynareOutput.exo_simul = zeros(samplesize,number_of_shocks);
-    DynareOutput.exo_simul(:,positive_var_indx) = DynareOutput.bnlms.shocks;
-    innovations = DynareOutput.exo_simul;
+    % Put the simulated innovations in oo_.exo_simul.
+    oo_.exo_simul = zeros(samplesize,number_of_shocks);
+    oo_.exo_simul(:,positive_var_indx) = oo_.bnlms.shocks;
+    innovations = oo_.exo_simul;
 else
-    DynareOutput.exo_simul = innovations; % innovations
+    oo_.exo_simul = innovations; % innovations
 end
 
 % Initialization of the returned simulations.
-DynareOutput.endo_simul = NaN(DynareModel.endo_nbr, samplesize+initialconditions.nobs);
+oo_.endo_simul = NaN(M_.endo_nbr, samplesize+initialconditions.nobs);
 for i=1:length(endonames)
     if ismember(endonames{i}, initialconditions.name)
-        DynareOutput.endo_simul(i,1:initialconditions.nobs) = transpose(initialconditions{endonames{i}}.data);
+        oo_.endo_simul(i,1:initialconditions.nobs) = transpose(initialconditions{endonames{i}}.data);
     end
 end
 
 % Initialization of the array for the exogenous variables.
-DynareOutput.exo_simul = [NaN(initialconditions.nobs, DynareModel.exo_nbr); DynareOutput.exo_simul ];
+oo_.exo_simul = [NaN(initialconditions.nobs, M_.exo_nbr); oo_.exo_simul ];
 for i=1:length(exonames)
     if ismember(exonames{i}, initialconditions.name)
-        DynareOutput.exo_simul(1:initialconditions.nobs, i) = initialconditions{exonames{i}}.data;
+        oo_.exo_simul(1:initialconditions.nobs, i) = initialconditions{exonames{i}}.data;
     end
 end
 
 
 if nargout>8
-    nx = size(DynareOutput.exo_simul,2);
-    ny0 = nnz(DynareModel.lead_lag_incidence(2,:));
-    ny1 = nnz(DynareModel.lead_lag_incidence(1,:));
-    iy1 = find(DynareModel.lead_lag_incidence(1,:)>0);
-    idx = 1:DynareModel.endo_nbr;
-    jdx = idx+ny1;
-    % Get the name of the dynamic model routine.
-    model_dynamic = str2func([DynareModel.fname,'.dynamic']);
+    % Get function handles to the dynamic model routines.
+    dynamic_resid = str2func([M_.fname,'.sparse.dynamic_resid']);
+    dynamic_g1 = str2func([M_.fname,'.sparse.dynamic_g1']);
     % initialization of vector y.
-    y = NaN(length(idx)+ny1,1);
-end
\ No newline at end of file
+    y = NaN(3*M_.endo_nbr,1);
+end
