@@ -14,7 +14,7 @@ function varlist = check_list_of_variables(options_, M_, varlist)
 %
 % SPECIAL REQUIREMENTS
 
-% Copyright (C) 2003-2018 Dynare Team
+% Copyright © 2003-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -41,7 +41,7 @@ if options_.dsge_var && options_.bayesian_irf
         for i=1:size(varlist,1)
             idx = strmatch(varlist{i}, options_.varobs, 'exact');
             if isempty(idx)
-                disp(sprintf('%s is not an observed variable!', varlist{i}))
+                dprintf('%s is not an observed variable!', varlist{i})
                 msg = true;
             end
         end
@@ -72,7 +72,7 @@ elseif isempty(varlist) && ~isempty(options_.endo_vars_for_moment_computations_i
     end
 elseif isempty(varlist) && isempty(options_.endo_vars_for_moment_computations_in_estimation)
     skipline()
-    disp(['You did not declare endogenous variables after the estimation/calib_smoother command.'])
+    disp('You did not declare endogenous variables after the estimation/calib_smoother command.')
     cas = '';
     if options_.bayesian_irf
         cas = 'Posterior IRFs';
@@ -169,4 +169,4 @@ while ~isempty(remain)
 end
 if index<max_number_of_words_per_line
     disp(line_of_text)
-end
\ No newline at end of file
+end
