@@ -55,8 +55,11 @@ switch ndseries
         hh = plot(o.data);
     end
     axis tight;
-    id = get(gca, 'XTick');
-    Dates = strings(o.dates(id));
+    %remove fractional ticks
+    xtick_values = xticks;
+    integer_indices = fix(xtick_values) == xtick_values;
+    xticks(xtick_values(integer_indices));
+    Dates = strings(o.dates(1:sum(integer_indices)));
     set(gca,'XTickLabel', Dates);
   case 2
     [o0, o1] = align(o, varargin{1});
