@@ -15,7 +15,7 @@ function r = subsref(o, S)
 %                     by applying a public method on `o`, or a dseries object built by extracting
 %                     a variable from `o`, or a dseries object containing a subsample.
 
-% Copyright © 2011-2023 Dynare Team
+% Copyright © 2011-2025 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -288,7 +288,7 @@ switch S(1).type
             error('dseries::subsref: It is not possible to populate a non empty dseries object!');
         end
     else
-        error('dseries::subsref: I have no idea of what you are trying to do!')
+        error('dseries::subsref: Invalid syntax')
     end
   case '{}'
     if iscellofchar(S(1).subs)
@@ -309,10 +309,10 @@ switch S(1).type
             r.tags.(tagnames{i}) = o.tags.(tagnames{i})(idx);
         end
     else
-        error('dseries::subsref: What the Hell are you tryin'' to do?!')
+        error('dseries::subsref: Invalid syntax')
     end
   otherwise
-    error('dseries::subsref: What the Hell are you doin'' here?!')
+    error('dseries::subsref: Invalid syntax')
 end
 
 S = shiftS(S,1);
