@@ -1,6 +1,6 @@
-function [info_convergence, endo_simul] = extended_path_homotopy(endo_simul, exo_simul, M, options, oo, pfm, ep, order, algo, method, debug)
+function [info_convergence, endo_simul] = extended_path_homotopy(endo_simul, exo_simul, M_, options_, oo_, pfm, ep, order, algo, method, debug)
 
-% Copyright (C) 2016-2017 Dynare Team
+% Copyright © 2016-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -31,30 +31,30 @@ if ismember(method, [1, 2])
     oldweight = weight;
     while noconvergence
         iteration = iteration + 1;
-        oo.endo_simul = endo_simul;
-        oo.endo_simul(:,1) = oo.steady_state + weight*(endo_simul0(:,1) - oo.steady_state);
-        oo.exo_simul = bsxfun(@plus, weight*exo_simul, (1-weight)*transpose(oo.exo_steady_state));
+        oo_.endo_simul = endo_simul;
+        oo_.endo_simul(:,1) = oo_.steady_state + weight*(endo_simul0(:,1) - oo_.steady_state);
+        oo_.exo_simul = bsxfun(@plus, weight*exo_simul, (1-weight)*transpose(oo_.exo_steady_state));
         if order==0
-            tmp = perfect_foresight_solver_core(M, options, oo);
+            [endo_simul_new, success] = perfect_foresight_solver_core(oo_.endo_simul, oo_.exo_simul, oo_.steady_state, oo_.exo_steady_state, M_, options_);
         else
             switch(algo)
               case 0
-                [flag, tmp.endo_simul] = ...
+                [flag, endo_simul_new] = ...
                     solve_stochastic_perfect_foresight_model(endo_simul, exo_simul, pfm, ep.stochastic.quadrature.nodes, ep.stochastic.order);
               case 1
-                [flag, tmp.endo_simul] = ...
-                    solve_stochastic_perfect_foresight_model_1(endo_simul, exo_simul, options, pfm, ep.stochastic.order);
+                [flag, endo_simul_new] = ...
+                    solve_stochastic_perfect_foresight_model_1(endo_simul, exo_simul, options_, pfm, ep.stochastic.order);
             end
         end
         if isequal(order, 0)
             % Logical variable flag is false iff the solver fails.
-            flag = ~tmp.deterministic_simulation.status;
+            flag = success;
         else
             % Fix convention issue on the value of flag.
             flag = ~flag;
         end
         if debug
-            disp(sprintf('%s\t %1.8f\t %s',int2str(iteration),weight,int2str(flag)))
+            dprintf('%u\t %1.8f\t %u', iteration, weight, flag)
         end
         state(2:end) = state(1:end-1);
         state(1) = flag;
@@ -70,7 +70,7 @@ if ismember(method, [1, 2])
             oldweight = weight;
             weight = min(weight*increase_factor, 1);
             increase_flag = true;
-            endo_simul = tmp.endo_simul;
+            endo_simul = endo_simul_new;
         else
             if increase_flag
                 weight = oldweight + (weight-oldweight)/100;
@@ -99,29 +99,29 @@ if isequal(method, 3) || (isequal(method, 2) && noconvergence)
     nweights = length(weights);
     while noconvergence
         weight = weights(index);
-        oo.endo_simul = endo_simul;
-        oo.exo_simul = bsxfun(@plus, weight*exo_simul, (1-weight)*transpose(oo.exo_steady_state));
+        oo_.endo_simul = endo_simul;
+        oo_.exo_simul = bsxfun(@plus, weight*exo_simul, (1-weight)*transpose(oo_.exo_steady_state));
         if order==0
-            tmp = perfect_foresight_solver_core(M, options, oo);
+            [endo_simul_new, success] = perfect_foresight_solver_core(oo_.endo_simul, oo_.exo_simul, oo_.steady_state, oo_.exo_steady_state, M_, options_);
         else
             switch(algo)
               case 0
-                [flag, tmp.endo_simul] = ...
+                [flag, endo_simul_new] = ...
                     solve_stochastic_perfect_foresight_model(endo_simul, exo_simul, pfm, ep.stochastic.quadrature.nodes, ep.stochastic.order);
               case 1
-                [flag, tmp.endo_simul] = ...
-                    solve_stochastic_perfect_foresight_model_1(endo_simul, exo_simul, options, pfm, ep.stochastic.order);
+                [flag, endo_simul_new] = ...
+                    solve_stochastic_perfect_foresight_model_1(endo_simul, exo_simul, options_, pfm, ep.stochastic.order);
             end
         end
         if isequal(order, 0)
             % Logical variable flag is false iff the solver fails.
-            flag = ~tmp.deterministic_simulation.status;
+            flag = success;
         else
             % Fix convention issue on the value of flag.
             flag = ~flag;
         end
         if debug
-            disp(sprintf('%s\t %1.8f\t %s',int2str(index),weight,int2str(flag)))
+            dprintf('%u\t %1.8f\t %u', index, weight, flag)
         end
         if flag
             jndex = index;
@@ -130,10 +130,10 @@ if isequal(method, 3) || (isequal(method, 2) && noconvergence)
                 continue
             end
             index = index+1;
-            endo_simul = tmp.endo_simul;
+            endo_simul = endo_simul_new;
         else
             break
         end
     end
     info_convergence = ~noconvergence;
-end
\ No newline at end of file
+end
