@@ -1,6 +1,6 @@
-function [shocks, spfm_exo_simul, innovations, DynareResults] = extended_path_shocks(innovations, ep, exogenousvariables, sample_size,DynareModel,DynareOptions, DynareResults)
-
-% Copyright (C) 2016-2017 Dynare Team
+function [shocks, spfm_exo_simul, innovations, oo_] = extended_path_shocks(innovations, ep, exogenousvariables, sample_size,M_,options_, oo_)
+% [shocks, spfm_exo_simul, innovations, oo_] = extended_path_shocks(innovations, ep, exogenousvariables, sample_size,M_,options_, oo_)
+% Copyright © 2016-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -21,13 +21,13 @@ function [shocks, spfm_exo_simul, innovations, DynareResults] = extended_path_sh
 if isempty(exogenousvariables)
     switch ep.innovation_distribution
       case 'gaussian'
-        shocks = zeros(sample_size, DynareModel.exo_nbr);
+        shocks = zeros(sample_size, M_.exo_nbr);
         shocks(:,innovations.positive_var_indx) = transpose(transpose(innovations.covariance_matrix_upper_cholesky)*randn(innovations.effective_number_of_shocks,sample_size));
       case 'calibrated'
-        options = DynareOptions;
+        options = options_;
         options.periods = options.ep.periods;
-        oo = make_ex_(DynareModel,options,DynareResults);
-        shocks = oo.exo_simul(2:end,:);
+        oo_local = make_ex_(M_,options,oo_);
+        shocks = oo_local.exo_simul(2:end,:);
       otherwise
         error(['extended_path:: ' ep.innovation_distribution ' distribution for the structural innovations is not (yet) implemented!'])
     end
@@ -37,5 +37,5 @@ else
 end
 
 % Copy the shocks in exo_simul
-DynareResults.exo_simul = shocks;
-spfm_exo_simul = repmat(DynareResults.exo_steady_state',ep.periods+2,1);
\ No newline at end of file
+oo_.exo_simul = shocks;
+spfm_exo_simul = repmat(oo_.exo_steady_state',ep.periods+2,1);
\ No newline at end of file
