@@ -148,7 +148,7 @@ if info(1)
                 info(1) == 411 || info(1) == 412 || info(1) == 413 % logarithmic reduction
         %meaningful second entry of output that can be used
         fval = Inf;
-        if isnan(info(2))
+        if ~isfinite(info(2))
             info(4) = 0.1;
         else
             info(4) = info(2);
@@ -173,7 +173,11 @@ end
 info=endogenous_prior_restrictions(T,R,M_,options_,dr,endo_steady_state,exo_steady_state,exo_det_steady_state);
 if info(1)
     fval = Inf;
-    info(4)=info(2);
+    if ~isfinite(info(2))
+        info(4) = 0.1;
+    else
+        info(4) = info(2);
+    end
     exit_flag = 0;
     if analytic_derivation
         DLIK=ones(length(xparam1),1);
