@@ -14,7 +14,7 @@ function m = moments(X,order)
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2009-2017 Dynare Team
+% Copyright © 2009-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -40,7 +40,7 @@ switch order
     if round(order)-order
         error('The second input argument (order) has to be an integer!')
     end
-    [T,n] = size(X);
+    [~,n] = size(X);
     c = mean(X);
     m = zeros(n,1);
     for i=1:n
