@@ -6,7 +6,7 @@ function ms_mardd(options_)
 %
 % Tao Zha, September 1999.  Quick revisions, May 2003.  Final revision, September 2004.
 
-% Copyright (C) 2011-2017 Dynare Team
+% Copyright © 2011-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -89,7 +89,7 @@ vlog_Y_a = -0.5*nvar*fss*log(2*pi) + fss*log(abs(det(A0xhat))) + Yexpt
 logMarLHres = 0;   % Initialize log of the marginal likelihood (restricted or constant parameters).
 for ki=1:fss   %ndobs+1:fss     % Forward recursion to get the marginal likelihood.  See F on p.19 and pp. 48-49.
                %----  Restricted log marginal likelihood function (constant parameters).
-    [A0l,A0u] = lu(A0xhat);
+    [~,A0u] = lu(A0xhat);
     ada = sum(log(abs(diag(A0u))));   % log|A0|
     termexp = y(ki,:)*A0xhat - phi(ki,:)*Apxhat;   % 1-by-nvar
     logMarLHres = logMarLHres - (0.5*nvar)*log(2*pi) + ada - 0.5*termexp*termexp';  % log value
@@ -121,7 +121,7 @@ vlog_a0_Yao = zeros(nvar,1);
 vlog=zeros(ndraws2,1);
 for k=1:nvar
     bk = Uiconst{k}'*A0xhat(:,k);
-    indx_ks=[k:nvar];  % the columns that exclude 1-(k-1)th columns
+    indx_ks=k:nvar;  % the columns that exclude 1-(k-1)th columns
     A0gbs0 = A0hat;   % starting at some point such as the peak
     nk = n0(k);
 
@@ -130,7 +130,7 @@ for k=1:nvar
         for draws = 1:ndraws1
             if ~mod(draws,nbuffer)
                 skipline()
-                disp(sprintf('The %dth column or equation in A0 with %d 1st tossed-away draws in Gibbs',k,draws))
+                dprintf('The %dth column or equation in A0 with %d 1st tossed-away draws in Gibbs', k, draws)
             end
             A0gbs1 = fn_gibbsrvar(A0gbs0,UT,nvar,fss,n0,indx_ks);
             A0gbs0=A0gbs1;    % repeat the Gibbs sampling
@@ -141,14 +141,14 @@ for k=1:nvar
         for draws = 1:ndraws2
             if ~mod(draws,nbuffer)
                 skipline()
-                disp(sprintf('The %dth column or equation in A0 with %d usable draws in Gibbs',k,draws))
+                dprintf('The %dth column or equation in A0 with %d usable draws in Gibbs', k, draws)
             end
             [A0gbs1, Wcell] = fn_gibbsrvar(A0gbs0,UT,nvar,fss,n0,indx_ks);
             %------ See p.71, Forecast (II).
             %------ Computing p(a0_k|Y,a_others) at some point such as the peak along the dimensions of indx_ks.
             Vk = Tinv{k}\Wcell{k};  %V_k on p.71 of Forecast (II).
             gbeta = Vk\bk;  % inv(V_k)*b_k on p.71 of Forecast (II) where alpha_k = b_k in our notation.
-            [Vtq,Vtr]=qr(Vk',0);  %To get inv(V_k)'*inv(V_k) in (*) on p.71 of Forecast (II).
+            [~,Vtr]=qr(Vk',0);  %To get inv(V_k)'*inv(V_k) in (*) on p.71 of Forecast (II).
                                   %
             vlog(draws) = 0.5*(fss+nk)*log(fss)-log(abs(det(Vk)))-0.5*(nk-1)*log(2*pi)-...
                 0.5*(fss+1)*log(2)-gammaln(0.5*(fss+1))+fss*log(abs(gbeta(1)))-...
@@ -163,13 +163,13 @@ for k=1:nvar
         % The log value of p(a0_k|Y,a_others) where a_others: other a's at some point such as the peak of ONLY some a0's
     else
         skipline()
-        disp(sprintf('The last(6th) column or equation in A0 with no Gibbs draws'))
-        [A0gbs1, Wcell] = fn_gibbsrvar(A0gbs0,UT,nvar,fss,n0,indx_ks)
+        disp('The last(6th) column or equation in A0 with no Gibbs draws')
+        [~, Wcell] = fn_gibbsrvar(A0gbs0,UT,nvar,fss,n0,indx_ks)
         %------ See p.71, Forecast (II).
         %------ Computing p(a0_k|Y,a_others) at some point such as the peak along the dimensions of indx_ks.
         Vk = Tinv{k}\Wcell{k};  %V_k on p.71 of Forecast (II).
         gbeta = Vk\bk;  % inv(V_k)*b_k on p.71 of Forecast (II) where alpha_k = b_k in our notation.
-        [Vtq,Vtr]=qr(Vk',0);  %To get inv(V_k)'*inv(V_k) in (*) on p.71 of Forecast (II).
+        [~,Vtr]=qr(Vk',0);  %To get inv(V_k)'*inv(V_k) in (*) on p.71 of Forecast (II).
                               %
         vloglast = 0.5*(fss+nk)*log(fss)-log(abs(det(Vk)))-0.5*(nk-1)*log(2*pi)-...
             0.5*(fss+1)*log(2)-gammaln(0.5*(fss+1))+fss*log(abs(gbeta(1)))-...
