@@ -15,13 +15,14 @@ function [x,fval,exitflag] = simplex_optimization_routine(objective_function,x,o
 %                                                       for verbose output
 %  o varargin               [cell of structures]      Structures to be passed to the objective function.
 %
-%     varargin{1} --> DynareDataset
-%     varargin{2} --> DatasetInfo
-%     varargin{3} --> DynareOptions
-%     varargin{4} --> Model
-%     varargin{5} --> EstimatedParameters
-%     varargin{6} --> BayesInfo
-%     varargin{1} --> DynareResults
+%     varargin{1} --> dataset_
+%     varargin{2} --> dataset_info
+%     varargin{3} --> options_
+%     varargin{4} --> M_
+%     varargin{5} --> estim_params_
+%     varargin{6} --> bayestopt_
+%     varargin{7} --> BoundsInfo
+%     varargin{8} --> oo_
 %
 % OUTPUTS
 %  o x                      [double]                  n*1 vector, estimate of the optimal inputs.
@@ -29,7 +30,7 @@ function [x,fval,exitflag] = simplex_optimization_routine(objective_function,x,o
 %  o exitflag               [integer]                 scalar equal to 0 or 1 (0 if the algorithm did not converge to
 %                                                     a minimum).
 
-% Copyright (C) 2010-2018 Dynare Team
+% Copyright © 2010-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -383,19 +384,19 @@ while (func_count < max_func_calls) && (iter_count < max_iterations) && (simplex
         fval_(1:length(fval)) = fval;
         if isfinite(fv(end)) && isfinite(fv(1))
             if fv(end)<0
-                disp(sprintf('%s  %s  %12.7E  %12.7E  %12.7E  %12.7E  %s', iter_, fval_, fv(1), fv(end), critF, critX, move))
+                dprintf('%s  %s  %12.7E  %12.7E  %12.7E  %12.7E  %s', iter_, fval_, fv(1), fv(end), critF, critX, move)
             else
                 if fv(1)>0
-                    disp(sprintf('%s  %s %12.7E %12.7E  %12.7E  %12.7E  %s', iter_, fval_, fv(1), fv(end), critF, critX, move))
+                    dprintf('%s  %s %12.7E %12.7E  %12.7E  %12.7E  %s', iter_, fval_, fv(1), fv(end), critF, critX, move)
                 else
-                    disp(sprintf('%s  %s  %12.7E %12.7E  %12.7E  %12.7E  %s', iter_, fval_, fv(1), fv(end), critF, critX, move))
+                    dprintf('%s  %s  %12.7E %12.7E  %12.7E  %12.7E  %s', iter_, fval_, fv(1), fv(end), critF, critX, move)
                 end
             end
         else
             if isfinite(fv(1))
-                disp(sprintf(['%s  %s  %12.7E                                 %12.7E  %s'], iter_, fval_, fv(1) , critX, move))
+                dprintf('%s  %s  %12.7E                                 %12.7E  %s', iter_, fval_, fv(1) , critX, move)
             else
-                disp(sprintf('%s  %s                                         %12.7E  %s', iter_, fval_, critX, move))
+                dprintf('%s  %s                                         %12.7E  %s', iter_, fval_, critX, move)
             end
         end
     end
@@ -550,4 +551,4 @@ for j = 1:n
 end
 % Sort by increasing order of the objective function values.
 [fv,sort_idx] = sort(fv);
-v = v(:,sort_idx);
\ No newline at end of file
+v = v(:,sort_idx);
