@@ -32,7 +32,7 @@ function [ErrorCode] = AnalyseComputationalEnvironment(DataInput, DataInputAdd)
 %   computer) is used.
 
 if ispc
-    [tempo, MasterName]=system('hostname');
+    [~, MasterName]=system('hostname');
     MasterName=deblank(MasterName);
 end
 
@@ -83,7 +83,7 @@ dynareParallelMkDir(RemoteTmpFolder,DataInput);
 % Currently when errors are detected execution simply stops and users can
 % fix configuration errors according to the error type.
 
-% Copyright (C) 2009-2017 Dynare Team
+% Copyright © 2009-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -104,7 +104,7 @@ dynareParallelMkDir(RemoteTmpFolder,DataInput);
 ErrorCode=0;
 
 
-for Node=1:length(DataInput) % To obtain a recoursive function remove the 'for'
+for Node=1:length(DataInput) % To obtain a recursive function remove the 'for'
                              % and use AnalyseComputationalEnvironment with differents input!
 
 
@@ -175,12 +175,12 @@ for Node=1:length(DataInput) % To obtain a recoursive function remove the 'for'
 
         if Environment
             if OScallerWindows
-                [si1 de1]=system(['ping ', DataInput(Node).ComputerName]);
+                [si1]=system(['ping ', DataInput(Node).ComputerName]);
             else
-                [si1 de1]=system(['ping ', DataInput(Node).ComputerName, ' -c 4']);
+                [si1]=system(['ping ', DataInput(Node).ComputerName, ' -c 4']);
             end
         else
-            [si1 de1]=system(['ping ', DataInput(Node).ComputerName]);
+            [si1]=system(['ping ', DataInput(Node).ComputerName]);
         end
 
         if (si1)
@@ -315,7 +315,7 @@ for Node=1:length(DataInput) % To obtain a recoursive function remove the 'for'
         % Build a command file to test the matlab execution and dynare path ...
 
         fid = fopen('Tracing.m', 'w+');
-        s1=(['fT = fopen(''MatlabOctaveIsOk.txt'',''w+'');\n']);
+        s1=('fT = fopen(''MatlabOctaveIsOk.txt'',''w+'');\n');
         s2='fclose(fT);\n';
         SBS=strfind(DataInput(Node).DynarePath,'\');
         DPStr=DataInput(Node).DynarePath;
@@ -329,17 +329,17 @@ for Node=1:length(DataInput) % To obtain a recoursive function remove the 'for'
             DPStrNew=[DPStrNew,DPStr(SBS(end)+1:end)];
         end
         s3=['addpath(''',DPStrNew,'''),\n'];
-        s4=['try,\n  dynareroot = dynare_config();\n'];
-        s41=(['  fT = fopen(''DynareIsOk.txt'',''w+'');\n']);
+        s4='try,\n  dynareroot = dynare_config();\n';
+        s41=('  fT = fopen(''DynareIsOk.txt'',''w+'');\n');
         s42='  fclose(fT);\n';
-        s5=['catch,\n'];
-        s51=(['  fT = fopen(''DynareFailed.txt'',''w+'');\n']);
+        s5='catch,\n';
+        s51=('  fT = fopen(''DynareFailed.txt'',''w+'');\n');
         s52='  fclose(fT);\n';
-        s6=['end,\n'];
-        s7=['if ismac,\n'];
-        s71=(['  fT = fopen(''IsMac.txt'',''w+'');\n']);
+        s6='end,\n';
+        s7='if ismac,\n';
+        s71=('  fT = fopen(''IsMac.txt'',''w+'');\n');
         s72='  fclose(fT);\n';
-        s8=['end,\n'];
+        s8='end,\n';
         send='exit';
         StrCommand=([s1,s2,s3,s4,s41,s42,s5,s51,s52,s6,s7,s71,s72,s8,send]);
 
@@ -387,15 +387,15 @@ for Node=1:length(DataInput) % To obtain a recoursive function remove the 'for'
         else
             if ~strcmp(DataInput(Node).ComputerName,MasterName) % run on remote machine
                 if  strfind([DataInput(Node).MatlabOctavePath], 'octave') % Hybrid computing Matlab(Master)->Octave(Slaves) and Vice Versa!
-                    [NonServeS NenServeD]=system(['start /B psexec \\',DataInput(Node).ComputerName,' -e -u ',DataInput(Node).UserName,' -p ',DataInput(Node).Password,' -W ',DataInput(Node).RemoteDrive,':\',DataInput(Node).RemoteDirectory,'\',RemoteTmpFolder ' -low   ',DataInput(Node).MatlabOctavePath,' Tracing.m']);
+                    system(['start /B psexec \\',DataInput(Node).ComputerName,' -e -u ',DataInput(Node).UserName,' -p ',DataInput(Node).Password,' -W ',DataInput(Node).RemoteDrive,':\',DataInput(Node).RemoteDirectory,'\',RemoteTmpFolder ' -low   ',DataInput(Node).MatlabOctavePath,' Tracing.m']);
                 else
-                    [NonServeS NenServeD]=system(['start /B psexec \\',DataInput(Node).ComputerName,' -e -u ',DataInput(Node).UserName,' -p ',DataInput(Node).Password,' -W ',DataInput(Node).RemoteDrive,':\',DataInput(Node).RemoteDirectory,'\',RemoteTmpFolder ' -low   ',DataInput(Node).MatlabOctavePath,' -nosplash -nodesktop -minimize -r Tracing']);
+                    system(['start /B psexec \\',DataInput(Node).ComputerName,' -e -u ',DataInput(Node).UserName,' -p ',DataInput(Node).Password,' -W ',DataInput(Node).RemoteDrive,':\',DataInput(Node).RemoteDirectory,'\',RemoteTmpFolder ' -low   ',DataInput(Node).MatlabOctavePath,' -nosplash -nodesktop -minimize -r Tracing']);
                 end
             else % run on local machine via the network: user and passwd cannot be used!
                 if  strfind([DataInput(Node).MatlabOctavePath], 'octave') % Hybrid computing Matlab(Master)->Octave(Slaves) and Vice Versa!
-                    [NonServeS NenServeD]=system(['start /B psexec \\',DataInput(Node).ComputerName,' -e ',' -W ',DataInput(Node).RemoteDrive,':\',DataInput(Node).RemoteDirectory,'\',RemoteTmpFolder ' -low   ',DataInput(Node).MatlabOctavePath,' Tracing.m']);
+                    system(['start /B psexec \\',DataInput(Node).ComputerName,' -e ',' -W ',DataInput(Node).RemoteDrive,':\',DataInput(Node).RemoteDirectory,'\',RemoteTmpFolder ' -low   ',DataInput(Node).MatlabOctavePath,' Tracing.m']);
                 else
-                    [NonServeS NenServeD]=system(['start /B psexec \\',DataInput(Node).ComputerName,' -e ',' -W ',DataInput(Node).RemoteDrive,':\',DataInput(Node).RemoteDirectory,'\',RemoteTmpFolder ' -low   ',DataInput(Node).MatlabOctavePath,' -nosplash -nodesktop -minimize -r Tracing']);
+                    system(['start /B psexec \\',DataInput(Node).ComputerName,' -e ',' -W ',DataInput(Node).RemoteDrive,':\',DataInput(Node).RemoteDirectory,'\',RemoteTmpFolder ' -low   ',DataInput(Node).MatlabOctavePath,' -nosplash -nodesktop -minimize -r Tracing']);
                 end
             end
 
@@ -530,7 +530,7 @@ for Node=1:length(DataInput) % To obtain a recoursive function remove the 'for'
                 Environment1 = 2;
             end
         else
-            command_string = ['psinfo \\'];
+            command_string = 'psinfo \\';
             [si0, de0] = system(command_string);
         end
     else
@@ -570,7 +570,7 @@ for Node=1:length(DataInput) % To obtain a recoursive function remove the 'for'
 
     % Questo controllo penso che si possa MIGLIORARE!!!!!
     if  isempty (RealCPUnbr) && Environment1==0
-        [si0 de0]=system(['psinfo \\',DataInput(Node).ComputerName]);
+        [~, de0]=system(['psinfo \\',DataInput(Node).ComputerName]);
     end
     RealCPUnbr=GiveCPUnumber(de0,Environment1);
 
@@ -629,4 +629,4 @@ for Node=1:length(DataInput) % To obtain a recoursive function remove the 'for'
 
     disp(['Test for Cluster computation, computer ',DataInput(Node).ComputerName, ' ..... Passed!'])
     skipline(2)
-end
\ No newline at end of file
+end
