@@ -12,7 +12,7 @@ function storeGlobalVars(fname,append)
 % None
 %
 %
-% Copyright (C) 2009-2017 Dynare Team
+% Copyright © 2009-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -31,14 +31,14 @@ function storeGlobalVars(fname,append)
 
 
 GlobalNames = who('global');
-% varlist = '';
+
 for j=1:length(GlobalNames)
     eval(['global ',GlobalNames{j},';']);
-    eval(['fGlobalVar.',GlobalNames{j},'=',GlobalNames{j},';']);
+    fGlobalVar.(GlobalNames{j}) = eval(GlobalNames{j});
 end
 
 if nargin<2
     save(fname,'fGlobalVar');
 else
     save(fname,'fGlobalVar','-append');
-end
\ No newline at end of file
+end
