@@ -1,18 +1,20 @@
-function perfect_foresight_setup()
+function oo_=perfect_foresight_setup(M_, options_, oo_)
 % Prepares a deterministic simulation, by filling oo_.exo_simul and oo_.endo_simul
 %
 % INPUTS
-%   None
+%   M_                  [structure] describing the model
+%   options_            [structure] describing the options
+%   oo_                 [structure] storing the results
 %
 % OUTPUTS
-%   none
+%   oo_                 [structure] storing the results
 %
 % ALGORITHM
 %
 % SPECIAL REQUIREMENTS
 %   none
 
-% Copyright (C) 1996-2021 Dynare Team
+% Copyright © 1996-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -29,8 +31,6 @@ function perfect_foresight_setup()
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
-global M_ options_ oo_
-
 test_for_deep_parameters_calibration(M_);
 
 if size(M_.lead_lag_incidence,2)-nnz(M_.lead_lag_incidence(M_.maximum_endo_lag+1,:)) > 0
@@ -64,5 +64,9 @@ if ~isempty(M_.det_shocks) && options_.periods<max([M_.det_shocks.periods])
     error('PERFECT_FORESIGHT_SETUP: Please check the declaration of the shocks or increase the value of the periods option.')
 end
 
+if options_.simul.endval_steady && M_.maximum_lead == 0
+    error('PERFECT_FORESIGHT_SETUP: Option endval_steady cannot be used on a purely backward or static model.')
+end
+
 oo_ = make_ex_(M_,options_,oo_);
-oo_ = make_y_(M_,options_,oo_);
\ No newline at end of file
+oo_ = make_y_(M_,options_,oo_);
