@@ -1,7 +1,7 @@
 function send_endogenous_variables_to_workspace()
 % Saves all the endogenous variables in matlab's workspace.
 
-% Copyright (C) 2009-2018 Dynare Team
+% Copyright © 2009-2018 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -20,5 +20,5 @@ function send_endogenous_variables_to_workspace()
 global M_ oo_
 
 for idx = 1:M_.endo_nbr
-    assignin('base', M_.endo_names{idx}, oo_.endo_simul(idx,:))
+    assignin('base', M_.endo_names{idx}, oo_.endo_simul(idx,:)')
 end
\ No newline at end of file
