@@ -14,19 +14,19 @@ function [y_,int_width,int_width_ME]=simultxdet(y0,ex,ex_det, iorder,var_list,M_
 %    options_:  Dynare options structure
 %
 % OUTPUTS:
-%   yf:          mean forecast
+%   yf:          mean forecast (in var_list order)
 %   int_width:   distance between upper bound and
-%                mean forecast
+%                mean forecast (in var_list order)
 %   int_width_ME:distance between upper bound and
-%                mean forecast when considering measurement error
+%                mean forecast when considering measurement error (in var_list order)
 %   int_width_ME:distance between upper bound and
-%                mean forecast when considering measurement error
+%                mean forecast when considering measurement error (in var_list order)
 %
 % The forecast horizon is equal to size(ex, 1).
 % The condition size(ex,1)+M_.maximum_lag=size(ex_det,1) must be verified
 %  for consistency.
 
-% Copyright © 2008-2018 Dynare Team
+% Copyright © 2008-2025 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -54,7 +54,6 @@ endo_nbr = M_.endo_nbr;
 exo_det_steady_state = oo_.exo_det_steady_state;
 nstatic = M_.nstatic;
 nspred = M_.nspred;
-nc = size(dr.ghx,2);
 iter = size(ex,1);
 if size(ex_det, 1) ~= iter+ykmin
     error('Size mismatch: number of forecasting periods for stochastic exogenous and deterministic exogenous don''t match')
@@ -85,6 +84,10 @@ else
         end
     end
 end
+if nargout==3 % add measurement error variance uncertainty for observables
+    [loc_H, loc_varlist] = ismember(options_.varobs, var_list);
+    loc_varlist(loc_varlist==0) = []; %location of observables in variable list
+end
 
 if iorder == 1
     for i = ykmin+1: iter+ykmin
@@ -109,7 +112,7 @@ elseif iorder == 2
         tempxu = kron(tempx,tempu);
         y_(dr.order_var,i) = dr.ys(dr.order_var)+dr.ghs2/2+dr.ghx*tempx+ ...
             dr.ghu*tempu+0.5*(dr.ghxx*tempxx+dr.ghuu*tempuu)+dr.ghxu* ...
-            tempxu;
+            tempxu; % in declaration order
         for j=1:min(ykmin+M_.exo_det_length+1-i,M_.exo_det_length)
             tempud = ex_det(i+j-1,:)'-exo_det_steady_state;
             tempudud = kron(tempud,tempud);
@@ -131,38 +134,40 @@ else
     error('simultxdet.m: order>2 not supported.')
 end
 
-[A,B] = kalman_transition_matrix(dr,nstatic+(1:nspred),1:nc);
+% Define union of requested and state variables
+[var_pos]=union(dr.inv_order_var(dr.state_var),dr.inv_order_var(ivar),'stable');
+% set state_pos to positions of state variables for inner part of
+% variance loop
+[~,state_pos] = ismember(dr.inv_order_var(dr.state_var),var_pos);
+% set var_list_pos to positions of var_list_ for reading out requested
+% variances
+[~,var_list_pos] = ismember(dr.inv_order_var(ivar),var_pos);
+ghx1 = dr.ghx(var_pos,:);
+ghu1 = dr.ghu(var_pos,:);
 
-inv_order_var = dr.inv_order_var;
-ghx1 = dr.ghx(inv_order_var(ivar),:);
-ghu1 = dr.ghu(inv_order_var(ivar),:);
-
-sigma_u = B*M_.Sigma_e*B';
-sigma_u1 = ghu1*M_.Sigma_e*ghu1';
-sigma_y = 0;
 
+sigma_y1 = zeros(size(ghx1,1),size(ghx1,1)); %no initial uncertainty about the states
 var_yf=NaN(iter,nvar); %initialize
 for i=1:iter
-    sigma_y1 = ghx1*sigma_y*ghx1'+sigma_u1; %only valid at first order, needs to be fixed, see https://git.dynare.org/Dynare/dynare/-/issues/1940
-    var_yf(i,:) = diag(sigma_y1)';
-    if i == iter
-        break
-    end
-    sigma_u = A*sigma_u*A';
-    sigma_y = sigma_y+sigma_u;
+    sigma_y1 = ghx1*sigma_y1(state_pos,state_pos)*ghx1'+ghu1*M_.Sigma_e*ghu1';%only valid at first order, needs to be fixed, see https://git.dynare.org/Dynare/dynare/-/issues/1940
+    var_yf(i,:) = diag(sigma_y1(var_list_pos,var_list_pos))'; % first period is initial condition without uncertainty
 end
 
 fact = norminv((1-options_.forecasts.conf_sig)/2,0,1);
 if nargout==3
     var_yf_ME=var_yf;
-    var_yf_ME(:,options_.varobs_id)=var_yf(:,options_.varobs_id)+repmat(diag(M_.H)',horizon,1);
-    int_width_ME = zeros(horizon,M_.endo_nbr);
+    if ~isempty(loc_varlist)
+        var_yf_ME(:,loc_varlist)=var_yf(:,loc_varlist)+repmat(diag(M_.H(loc_H,loc_H))',iter,1);
+    end
+    int_width_ME = zeros(iter,nvar);
 end
 
 int_width = zeros(iter,nvar);
 for i=1:nvar
-    int_width(:,i) = fact*sqrt(var_yf(:,i));
+    int_width(:,i) = -fact*sqrt(var_yf(:,i));
     if nargout==3
         int_width_ME(:,i) = -fact*sqrt(var_yf_ME(:,i));
     end
 end
+
+y_ = y_(ivar,:); %reorder from declaration to var_list order
