@@ -8,7 +8,7 @@ function flist = get_directory_description(basedir)
 % OUTPUTS
 %  - flist   [cell of strings], the files under basedir (and subfolders).
 
-% Copyright (C) 2013-2017 Dynare Team
+% Copyright © 2013-2017 Dynare Team
 %
 % This file is part of Dynare (m-unit-tests module).
 %
@@ -41,7 +41,7 @@ for f=1:length(dd)
             flist = { flist{:} r{:} };
         else
             % Filter out files without m extension.
-            [make, my, ext] = fileparts(dd(f).name);
+            [~, ~, ext] = fileparts(dd(f).name);
             if isequal(ext, '.m')
                 flist{length(flist)+1} = [basedir filesep dd(f).name];
             end
