@@ -1,5 +1,5 @@
 /*
- * Copyright © 2010-2020 Dynare Team
+ * Copyright © 2010-2023 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -17,52 +17,53 @@
  * along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+#include <cctype>
 #include <cstdlib>
 #include <cstring>
-#include <cctype>
 #include <dynmex.h>
 
 #include "modify_for_mex.h"
 
-int main(int nargs, char **args);
+int main(int nargs, char** args);
 
 void
-mexFunction(int nlhs, mxArray *plhs[],
-            int nrhs, const mxArray *prhs[])
+mexFunction(int nlhs, [[maybe_unused]] mxArray* plhs[], int nrhs, const mxArray* prhs[])
 {
   int nargs = 0;
-  const char *mainarg = "./a.out";
+  const char* mainarg = "./a.out";
 
   /*
    * Check args
    */
   if (nrhs != 1 || !mxIsChar(prhs[0]) || nlhs != 0)
-    mexErrMsgTxt("Error in MS-SBVAR MEX file: this function takes 1 string input argument and returns no output argument.");
+    mexErrMsgTxt("Error in MS-SBVAR MEX file: this function takes 1 string input argument and "
+                 "returns no output argument.");
 
   /*
    * Allocate memory
    */
-  int maxnargs = static_cast<int>(mxGetN(prhs[0])/2+1);
-  char *argument = static_cast<char *>(mxCalloc(mxGetN(prhs[0])+1, sizeof(char)));
-  char **args = static_cast<char **>(mxCalloc(maxnargs, sizeof(char *)));
+  int maxnargs = static_cast<int>(mxGetN(prhs[0]) / 2 + 1);
+  char* argument = static_cast<char*>(mxCalloc(mxGetN(prhs[0]) + 1, sizeof(char)));
+  char** args = static_cast<char**>(mxCalloc(maxnargs, sizeof(char*)));
   if (!argument || !args)
     mexErrMsgTxt("Error in MS-SBVAR MEX file: could not allocate memory. (1)");
 
   /*
    * Create argument string from prhs and parse to create args / nargs
    */
-  if (!(args[nargs] = static_cast<char *>(mxCalloc(strlen(mainarg)+1, sizeof(char)))))
+  if (!(args[nargs] = static_cast<char*>(mxCalloc(strlen(mainarg) + 1, sizeof(char)))))
     mexErrMsgTxt("Error in MS-SBVAR MEX file: could not allocate memory. (2)");
 
-  strcpy(args[nargs++], mainarg);
+  // Disabling security warning, since by construction the destination is large enough
+  strcpy(args[nargs++], mainarg); // NOLINT(clang-analyzer-security.insecureAPI.strcpy)
 
-  if (mxGetString(prhs[0], argument, mxGetN(prhs[0])+1))
+  if (mxGetString(prhs[0], argument, mxGetN(prhs[0]) + 1))
     mexErrMsgTxt("Error in MS-SBVAR MEX file: error using mxGetString.\n");
 
-  char *beginarg = argument;
+  char* beginarg = argument;
   while (int n = strcspn(beginarg, " "))
     {
-      if (!(args[nargs] = static_cast<char *>(mxCalloc(n+1, sizeof(char)))))
+      if (!(args[nargs] = static_cast<char*>(mxCalloc(n + 1, sizeof(char)))))
         mexErrMsgTxt("Error in MS-SBVAR MEX file: could not allocate memory. (3)");
 
       strncpy(args[nargs++], beginarg, n);
@@ -77,7 +78,7 @@ mexFunction(int nlhs, mxArray *plhs[],
     {
       main(nargs, args);
     }
-  catch (const char *str)
+  catch (const char* str)
     {
       mexErrMsgTxt(str);
     }
