@@ -1,5 +1,5 @@
 /*
- * Copyright © 2010-2013 Dynare Team
+ * Copyright © 2010-2023 Dynare Team
  *
  * This file is part of Dynare.
  *
@@ -17,24 +17,10 @@
  * along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#if defined(MATLAB_MEX_FILE) || defined(OCTAVE_MEX_FILE)
+#include <dynmex.h>
 
-# include <dynmex.h>
-
-# ifdef __cplusplus
-extern "C"
+extern "C" [[noreturn]] void
+msExit([[maybe_unused]] int status)
 {
-# endif
-
-  int constant_seed;
-
-  void
-  msExit(int status)
-  {
-    throw "Error in MS-SBVAR MEX file.\n";
-  }
-
-# ifdef __cplusplus
+  throw "Error in MS-SBVAR MEX file.\n";
 }
-# endif
-#endif
