@@ -1,7 +1,7 @@
 /*
 ** Computes Quasi Monte-Carlo sequence.
 **
-** Copyright © 2010-2020 Dynare Team
+** Copyright © 2010-2023 Dynare Team
 **
 ** This file is part of Dynare (can be used outside Dynare).
 **
@@ -23,11 +23,11 @@
 
 #include <dynmex.h>
 
-#include "sobol.hh"
 #include "gaussian.hh"
+#include "sobol.hh"
 
 void
-mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
+mexFunction(int nlhs, mxArray* plhs[], int nrhs, const mxArray* prhs[])
 {
   /*
   ** INPUTS:
@@ -38,8 +38,10 @@ mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   **                                   1 ⇒ gaussian,
   **                                   2 ⇒ uniform on an hypershere.
   ** prhs[3]    [integer]    scalar, sequence size.
-  ** prhs[4]    [double]     dimension×2 array, lower and upper bounds of the hypercube (default is 0-1 in all dimensions) if prhs[2]==0,
-  **                         dimension×dimension array, covariance of the multivariate gaussian distribution of prhs[2]==1 (default is the identity matrix),
+  ** prhs[4]    [double]     dimension×2 array, lower and upper bounds of the hypercube (default is
+  **                         0-1 in all dimensions) if prhs[2]==0,
+  **                         dimension×dimension array, covariance of the multivariate gaussian
+  **                         distribution of prhs[2]==1 (default is the identity matrix),
   **                         scalar, radius of the hypershere if prhs[2]==2 (default is one).
   **
   ** OUTPUTS:
@@ -60,22 +62,30 @@ mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   /*
   ** Test the first input argument and assign it to dimension.
   */
-  if (!mxIsNumeric(prhs[0]))
-    mexErrMsgTxt("qmc_sequence:: First input (dimension) has to be a positive integer!");
+  if (!(mxIsScalar(prhs[0]) && mxIsNumeric(prhs[0])))
+    mexErrMsgTxt("qmc_sequence:: First input (dimension) has to be a numeric scalar!");
 
   int dimension = static_cast<int>(mxGetScalar(prhs[0]));
+  if (dimension <= 0)
+    mexErrMsgTxt("qmc_sequence:: First input (dimension) has to be a positive integer!");
+
   /*
   ** Test the second input argument and assign it to seed.
   */
   if (!(mxIsNumeric(prhs[1]) && mxIsClass(prhs[1], "int64")))
     mexErrMsgTxt("qmc_sequence:: Second input (seed) has to be an integer [int64]!");
 
-  int64_T seed = static_cast<int64_T>(mxGetScalar(prhs[1]));
+#if MX_HAS_INTERLEAVED_COMPLEX
+  int64_T seed = *mxGetInt64s(prhs[1]);
+#else
+  int64_T seed = *static_cast<int64_T*>(mxGetData(prhs[1]));
+#endif
+
   /*
   ** Test the third input argument and assign it to type (kind of QMC sequence).
   */
   int error_flag_3 = 0;
-  if (!mxIsNumeric(prhs[2]))
+  if (!(mxIsScalar(prhs[2]) && mxIsNumeric(prhs[2])))
     error_flag_3 = 1;
 
   int type = static_cast<int>(mxGetScalar(prhs[2]));
@@ -83,44 +93,61 @@ mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
     error_flag_3 = 1;
 
   if (error_flag_3 == 1)
-    mexErrMsgTxt("qmc_sequence:: Third input (type of QMC sequence) has to be an integer equal to 0, 1 or 2!");
+    mexErrMsgTxt("qmc_sequence:: Third input (type of QMC sequence) has to be an integer equal to "
+                 "0, 1 or 2!");
 
   /*
   ** Test dimension ≥ 2 when type==2
   */
   if (type == 2 && dimension < 2)
-    mexErrMsgTxt("qmc_sequence:: First input (dimension) has to be greater than 1 for a uniform QMC on an hypershere!");
+    mexErrMsgTxt("qmc_sequence:: First input (dimension) has to be greater than 1 for a uniform "
+                 "QMC on an hypershere!");
 
   else if (dimension > DIM_MAX)
-    mexErrMsgTxt(("qmc_sequence:: First input (dimension) has to be smaller than " + to_string(DIM_MAX) + " !").c_str());
+    mexErrMsgTxt(("qmc_sequence:: First input (dimension) has to be smaller than "
+                  + to_string(DIM_MAX) + " !")
+                     .c_str());
 
   /*
   ** Test the optional fourth input argument and assign it to sequence_size.
   */
-  if (nrhs > 3 && !mxIsNumeric(prhs[3]))
-    mexErrMsgTxt("qmc_sequence:: Fourth input (qmc sequence size) has to be a positive integer!");
+  if (nrhs > 3 && !(mxIsScalar(prhs[3]) && mxIsNumeric(prhs[3])))
+    mexErrMsgTxt("qmc_sequence:: Fourth input (qmc sequence size) has to be a numeric scalar!");
 
   int sequence_size;
   if (nrhs > 3)
-    sequence_size = static_cast<int>(mxGetScalar(prhs[3]));
+    {
+      sequence_size = static_cast<int>(mxGetScalar(prhs[3]));
+      if (sequence_size <= 0)
+        mexErrMsgTxt(
+            "qmc_sequence:: Fourth input (qmc sequence size) has to be a positive integer!");
+    }
   else
     sequence_size = 1;
 
   /*
   ** Test the optional fifth input argument and assign it to lower_and_upper_bounds.
   */
-  if (nrhs > 4 && type == 0 && mxGetN(prhs[4]) != 2) // Sequence of uniformly distributed numbers in an hypercube
-    mexErrMsgTxt("qmc_sequence:: The fifth input argument must be an array with two columns!");
+  if (nrhs > 4 && type == 0
+      && !(mxIsDouble(prhs[4]) && !mxIsComplex(prhs[4]) && !mxIsSparse(prhs[4])
+           && mxGetN(prhs[4]) == 2
+           && static_cast<int>(mxGetM(prhs[4]))
+                  == dimension)) // Sequence of uniformly distributed numbers in an hypercube
+    mexErrMsgTxt("qmc_sequence:: The fifth input argument must be a real dense array with two "
+                 "columns and number of lines equal to dimension (first input argument)!");
 
-  if (nrhs > 4 && type == 0 && static_cast<int>(mxGetM(prhs[4])) != dimension)
-    mexErrMsgTxt("qmc_sequence:: The fourth input argument must be an array with a number of lines equal to dimension (first input argument)!");
+  if (nrhs > 4 && type == 1
+      && !(mxIsDouble(prhs[4]) && !mxIsComplex(prhs[4]) && !mxIsSparse(prhs[4])
+           && static_cast<int>(mxGetN(prhs[4])) == dimension
+           && static_cast<int>(mxGetM(prhs[4]))
+                  == dimension)) // Sequence of normally distributed numbers
+    mexErrMsgTxt("qmc_sequence:: The fifth input argument must be a real dense square matrix "
+                 "(whose dimension is given by the first input argument)!");
 
-  if (nrhs > 4 && type == 1 && !(static_cast<int>(mxGetN(prhs[4])) == dimension
-                                 && static_cast<int>(mxGetM(prhs[4])) == dimension)) // Sequence of normally distributed numbers
-    mexErrMsgTxt("qmc_sequence:: The fifth input argument must be a squared matrix (whose dimension is given by the first input argument)!");
-
-  if (nrhs > 4 && type == 2 && !(mxGetN(prhs[4]) == 1 && mxGetM(prhs[4]) == 1)) // Sequence of uniformly distributed numbers on a hypershere
-    mexErrMsgTxt("qmc_sequence:: The fifth input argument must be a positive scalar!");
+  if (nrhs > 4 && type == 2
+      && !(mxIsScalar(prhs[4])
+           && mxIsNumeric(prhs[4]))) // Sequence of uniformly distributed numbers on a hypershere
+    mexErrMsgTxt("qmc_sequence:: The fifth input argument must be a numeric scalar!");
 
   const double *lower_bounds = nullptr, *upper_bounds = nullptr;
   int unit_hypercube_flag = 1;
@@ -130,7 +157,7 @@ mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
       upper_bounds = lower_bounds + dimension;
       unit_hypercube_flag = 0;
     }
-  const double *cholcov = nullptr;
+  const double* cholcov = nullptr;
   int identity_covariance_matrix = 1;
   if (type == 1 && nrhs > 4)
     {
@@ -141,14 +168,16 @@ mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   int unit_radius = 1;
   if (type == 2 && nrhs > 4)
     {
-      radius = *mxGetPr(prhs[4]);
+      radius = mxGetScalar(prhs[4]);
+      if (radius <= 0)
+        mexErrMsgTxt("qmc_sequence:: The fifth input argument must be a positive real number!");
       unit_radius = 0;
     }
   /*
   ** Initialize outputs of the mex file.
   */
   plhs[0] = mxCreateDoubleMatrix(dimension, sequence_size, mxREAL);
-  double *qmc_draws = mxGetPr(plhs[0]);
+  double* qmc_draws = mxGetPr(plhs[0]);
   int64_T seed_out;
 
   if (sequence_size == 1)
@@ -164,7 +193,7 @@ mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
   else if (type == 1) // Normal QMC sequence in ℝⁿ
     {
       if (identity_covariance_matrix == 1)
-        icdfm(dimension*sequence_size, qmc_draws);
+        icdfm(dimension * sequence_size, qmc_draws);
       else
         icdfmSigma(dimension, sequence_size, qmc_draws, cholcov);
     }
@@ -182,7 +211,7 @@ mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
 #if MX_HAS_INTERLEAVED_COMPLEX
       *mxGetInt64s(plhs[1]) = seed_out;
 #else
-      *(static_cast<int64_T *>(mxGetData(plhs[1]))) = seed_out;
+      *(static_cast<int64_T*>(mxGetData(plhs[1]))) = seed_out;
 #endif
     }
   if (nlhs >= 3)
