@@ -7,7 +7,7 @@ set -exo pipefail
 # MATLAB Online.
 
 X13ASVER=1-1-b60
-MATLABVER=R2024b
+MATLABVER=R2025b
 
 MATLABPATH=/opt/MATLAB/${MATLABVER}
 # TODO: change size and put white background for better rendering in MATLAB Add-Ons browser
@@ -21,6 +21,14 @@ cleanup ()
 }
 trap cleanup EXIT
 
+# Get X13 binary from the Census Bureau website if not cached, and unpack it into the temporary workspace
+# The binary from Ubuntu has some shared library dependencies, so it is safer to use a static binary
+X13ASTARBALL=x13as_ascii-v${X13ASVER}.tar.gz
+if [[ ! -f ${X13ASTARBALL} ]]; then
+    wget --no-verbose --retry-connrefused --retry-on-host-error https://www.dynare.org/pkg-build/x13as/linux/${X13ASTARBALL}
+fi
+tar -xf ${X13ASTARBALL} -C "${tmpdir}"
+
 pushd ../..
 meson setup -Dbuild_for=matlab -Dmatlab_path="$MATLABPATH" -Dbuildtype=release -Dprefer_static=true "$tmpdir"/build-matlab-online
 
@@ -43,20 +51,11 @@ cd ..
 strip usr/local/bin/dynare-preprocessor
 strip usr/local/lib/dynare/mex/matlab/*.mexa64
 
-# Get X13 binary from the Census Bureau website
-# The binary from Ubuntu has some shared library dependencies, so it is safer to use a static binary
-wget -q https://www2.census.gov/software/x-13arima-seats/x13as/unix-linux/program-archives/x13as_ascii-v${X13ASVER}.tar.gz
-tar xf x13as_ascii-v${X13ASVER}.tar.gz
-
-# Populate staging area for the zip
+# Populate staging area for the .mltbx archive
 cp -pRL usr/local/lib/dynare dynare # -L is needed to dereference the preprocessor symlink
 mkdir -p dynare/matlab/dseries/externals/x13/linux/64
 cp -p x13as/x13as_ascii dynare/matlab/dseries/externals/x13/linux/64/x13as
 
-# zip dynare
-cd dynare
-zip -q -r "$tmpdir"/dynare.zip *
-
 # make toolbox
 popd
-"$MATLABPATH/bin/matlab" -batch "packageDynare('$tmpdir/dynare.zip', '$DYNAREVER', '$DYNAREVER_SANITIZED', '$DYNARE_PNG_LOGO')"
+"$MATLABPATH/bin/matlab" -batch "packageDynare('$tmpdir/dynare', '$DYNAREVER', '$DYNAREVER_SANITIZED', '$DYNARE_PNG_LOGO')"
