@@ -84,7 +84,7 @@ try
     ds1 = histvalf_initvalf(caller, M, options);
     error('This test didn''t catch the error')
 catch me
-    if ~strcmp(me.message, strcat('INITVAL_FILE: FIST_OBS, LAST_OBS and NOBS contain', ...
+    if ~strcmp(me.message, strcat('INITVAL_FILE: FIRST_OBS, LAST_OBS and NOBS contain', ...
                                   ' inconsistent information. Use only two of these', ...
                                   ' options.'))
         failed_tests = cat(1, failed_tests, 'Wrong nobs error message' );
