@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# Produces Windows packages of Dynare (executable installer, 7z and zip archives).
+# Produces Windows packages of Dynare (executable installer and 7z archives).
 #
 # The binaries are cross compiled for Windows (64-bit), Octave and MATLAB
 # (all supported versions).
@@ -33,11 +33,12 @@ ROOT_DIRECTORY=$(dirname "$(readlink -f "$0")")
 [[ -d "$ROOT_DIRECTORY"/../build-win-matlab ]] && { echo "Please remove the build-win-matlab directory" 2>&1; exit 1; }
 [[ -d "$ROOT_DIRECTORY"/../build-win-octave ]] && { echo "Please remove the build-win-octave directory" 2>&1; exit 1; }
 
-# Create TMP folder and make sure it is deleted upon exit
+# Create temporary folder and make sure it is deleted upon exit (along with /tmp/windeps)
 TMP_DIRECTORY=$(mktemp -d)
 cleanup()
 {
     [[ -z $TMP_DIRECTORY ]] || rm -rf -- "$TMP_DIRECTORY"
+    rm -rf /tmp/windeps
 }
 trap cleanup EXIT
 
@@ -106,9 +107,9 @@ mkdir -p exe
 BASENAME=dynare-$VERSION
 mv dynare-"$VERSION"-win.exe "$ROOT_DIRECTORY"/exe/"$BASENAME"-win.exe
 
-## Create 7z and zip archives (for people not allowed to download/execute the installer)
+## Create 7z archive (for people not allowed to download/execute the installer)
 
-# Set name of the root directory in the 7z and zip archives
+# Set name of the root directory in the 7z archive
 ZIPDIR="$TMP_DIRECTORY"/"$BASENAME"
 mkdir -p "$ZIPDIR"
 
@@ -119,8 +120,8 @@ cp -p windows/README.txt "$ZIPDIR"
 cp -pr windows/deps/mingw64 "$ZIPDIR"
 mkdir -p "$ZIPDIR"/contrib/ms-sbvar/TZcode
 cp -pr contrib/ms-sbvar/TZcode/MatlabFiles "$ZIPDIR"/contrib/ms-sbvar/TZcode
-mkdir -p "$ZIPDIR"/mex/matlab/win64-9.5-25.1
-cp -p build-win-matlab/*.mexw64 "$ZIPDIR"/mex/matlab/win64-9.5-25.1
+mkdir -p "$ZIPDIR"/mex/matlab/win64-9.5-25.2
+cp -p build-win-matlab/*.mexw64 "$ZIPDIR"/mex/matlab/win64-9.5-25.2
 mkdir -p "$ZIPDIR"/mex/octave/win64
 cp -p build-win-octave/*.mex "$ZIPDIR"/mex/octave/win64
 mkdir "$ZIPDIR"/preprocessor
@@ -139,8 +140,5 @@ cp -pr build-doc/dynare-manual.html "$ZIPDIR"/doc
 
 cd "$TMP_DIRECTORY"
 
-mkdir -p "$ROOT_DIRECTORY"/zip
-zip -9 --quiet --recurse-paths "$ROOT_DIRECTORY"/zip/"$BASENAME"-win.zip "$BASENAME"
-
 mkdir -p "$ROOT_DIRECTORY"/7z
 7zr a -mx=9 "$ROOT_DIRECTORY"/7z/"$BASENAME"-win.7z "$BASENAME"
